==> timew_1.4.3+ds.1.orig.tar.xz: timewarrior/src/libshared/src/RX.h <==
////////////////////////////////////////////////////////////////////////////////
//
// Copyright 2006 - 2021, Paul Beckingham, Federico Hernandez.
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
//
// http://www.opensource.org/licenses/mit-license.php
//
////////////////////////////////////////////////////////////////////////////////

#ifndef INCLUDED_RX
#define INCLUDED_RX

#include <string>
#include <vector>
#include <regex.h>

class RX
{
public:
  RX ();
  RX (const std::string&, bool caseSensitive = true);
  RX (const RX&);
  ~RX ();
  RX& operator= (const RX&);

  bool match (const std::string&);
  bool match (std::vector<std::string>&, const std::string&);
  bool match (std::vector <int>&, std::vector <int>&, const std::string&);

private:
  void compile ();

private:
  bool _compiled       {false};
  std::string _pattern {};
  bool _case_sensitive {false};
  regex_t _regex;
};

#endif

==> timew_1.7.1+ds.1.orig.tar.xz: timewarrior/src/libshared/src/RX.h <==
////////////////////////////////////////////////////////////////////////////////
//
// Copyright 2016 - 2017, 2019 - 2021, 2023, Gothenburg Bit Factory.
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
//
// http://www.opensource.org/licenses/mit-license.php
//
////////////////////////////////////////////////////////////////////////////////

#ifndef INCLUDED_RX
#define INCLUDED_RX

#include <regex.h>
#include <string>
#include <vector>

class RX
{
public:
  RX ();
  RX (const std::string&, bool case_sensitive = true);
  RX (const RX&);
  ~RX ();
  RX& operator= (const RX&);

  bool match (const std::string&);
  bool match (std::vector<std::string>&, const std::string&);
  bool match (std::vector <int>&, std::vector <int>&, const std::string&);

private:
  void compile ();

private:
  bool _compiled       {false};
  std::string _pattern {};
  bool _case_sensitive {false};
  regex_t _regex;
};

#endif
